@@ -11,8 +11,8 @@ use namespace::autoclean;
 use Moose::Role;
 
 use MooseX::App::Utils;
-use Path::Class;
 use Module::Pluggable::Object;
+use File::Basename qw();
 no if $] >= 5.018000, warnings => qw(experimental::smartmatch);
 
 has 'app_messageclass' => (
@@ -40,7 +40,10 @@ has 'app_exclude' => (
 has 'app_base' => (
     is          => 'rw',
     isa         => 'Str',
-    default     => sub { Path::Class::File->new($0)->basename },
+    lazy        => 1,
+    default     => sub {
+        return File::Basename::basename($0);
+    },
 );
 
 has 'app_strict' => (
