@@ -31,11 +31,16 @@ option 'another_option' => (
     cmd_tags      => ['Not important'],
 );
 
+option 'list' => (
+    is            => 'rw',
+    isa           => 'ArrayRef[Maybe[Str]]',
+);
+
 has 'private' => (
     is              => 'rw',
     isa             => 'Str',
 );
- 
+
 sub run {
     my ($self) = @_;
     print "RUN:".($self->some_option||'').":".($self->another_option||'');
